summaryrefslogtreecommitdiff
path: root/lib/libc/time/tzfile.h
diff options
context:
space:
mode:
authorTodd C. Miller <millert@cvs.openbsd.org>1998-01-18 23:25:05 +0000
committerTodd C. Miller <millert@cvs.openbsd.org>1998-01-18 23:25:05 +0000
commite747c2b62dea9442f4e6794bc8da331056ce5610 (patch)
tree4ebc364ea4749ee4ed950d2d93c4e82ab91253f9 /lib/libc/time/tzfile.h
parent9e85b2758588ab99d68e603c2194c8d030f0970b (diff)
tzcode1998b from ftp://elsie.nci.nih.gov/pub
Diffstat (limited to 'lib/libc/time/tzfile.h')
-rw-r--r--lib/libc/time/tzfile.h13
1 files changed, 8 insertions, 5 deletions
diff --git a/lib/libc/time/tzfile.h b/lib/libc/time/tzfile.h
index 82e6852936e..40331f46bc6 100644
--- a/lib/libc/time/tzfile.h
+++ b/lib/libc/time/tzfile.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: tzfile.h,v 1.4 1997/01/14 03:16:52 millert Exp $ */
+/* $OpenBSD: tzfile.h,v 1.5 1998/01/18 23:25:00 millert Exp $ */
#ifndef TZFILE_H
@@ -24,7 +24,7 @@
#if 0
#ifndef lint
#ifndef NOID
-static char tzfilehid[] = "@(#)tzfile.h 7.9";
+static char tzfilehid[] = "@(#)tzfile.h 7.14";
#endif /* !defined NOID */
#endif /* !defined lint */
#endif
@@ -49,8 +49,11 @@ static char tzfilehid[] = "@(#)tzfile.h 7.9";
** Each file begins with. . .
*/
+#define TZ_MAGIC "TZif"
+
struct tzhead {
- char tzh_reserved[20]; /* reserved for future use */
+ char tzh_magic[4]; /* TZ_MAGIC */
+ char tzh_reserved[16]; /* reserved for future use */
char tzh_ttisgmtcnt[4]; /* coded number of trans. time flags */
char tzh_ttisstdcnt[4]; /* coded number of trans. time flags */
char tzh_leapcnt[4]; /* coded number of leap seconds */
@@ -65,7 +68,7 @@ struct tzhead {
** tzh_timecnt (char [4])s coded transition times a la time(2)
** tzh_timecnt (unsigned char)s types of local time starting at above
** tzh_typecnt repetitions of
-** one (char [4]) coded GMT offset in seconds
+** one (char [4]) coded UTC offset in seconds
** one (unsigned char) used to set tm_isdst
** one (unsigned char) that's an abbreviation list index
** tzh_charcnt (char)s '\0'-terminated zone abbreviations
@@ -78,7 +81,7 @@ struct tzhead {
** if absent, transition times are
** assumed to be wall clock time
** tzh_ttisgmtcnt (char)s indexed by type; if TRUE, transition
-** time is GMT, if FALSE,
+** time is UTC, if FALSE,
** transition time is local time
** if absent, transition times are
** assumed to be local time